@@ -170,33 +170,36 @@ add_send_options_data_to_item (EGwItem *item, ECalComponent *comp, icaltimezone
 			e_gw_item_set_reply_request (item, TRUE);
 			x_val = icalproperty_get_x (icalprop);
 			if (strcmp (x_val, "convenient")) {
-				const char *value;
+				char *value;
 				int i = atoi (x_val);
 				temp = icaltime_current_time_with_zone (default_zone ? default_zone : utc);
 				icaltime_adjust (&temp, i, 0, 0, 0);
 				icaltime_set_timezone (&temp, default_zone);
 				temp = icaltime_convert_to_zone (temp, utc);
 				value = icaltime_as_ical_string (temp);
-				e_gw_item_set_reply_within (item, (char *) value);
+				e_gw_item_set_reply_within (item, value);
+				g_free (value);
 			}
 		} else if (!strcmp (x_name, "X-EVOLUTION-OPTIONS-EXPIRE")) {
-			const char *expire = NULL;
+			char *expire = NULL;
 			x_val = icalproperty_get_x (icalprop);
 			temp = icaltime_current_time_with_zone (default_zone ? default_zone : utc);
 			icaltime_adjust (&temp, atoi (x_val), 0, 0, 0);
 			icaltime_set_timezone (&temp, default_zone);
 			temp = icaltime_convert_to_zone (temp, utc);
 			expire = icaltime_as_ical_string (temp);
-			e_gw_item_set_expires (item, (char *) expire);
+			e_gw_item_set_expires (item, expire);
+			g_free (expire);
 
 		} else if (!strcmp (x_name, "X-EVOLUTION-OPTIONS-DELAY")) {
-			const char *delay = NULL;
+			char *delay = NULL;
 			x_val = icalproperty_get_x (icalprop);
 			temp = icaltime_from_string (x_val);
 			icaltime_set_timezone (&temp, default_zone);
 			temp = icaltime_convert_to_zone (temp, utc);
 			delay = icaltime_as_ical_string (temp);
-			e_gw_item_set_delay_until (item, (char *) delay);
+			e_gw_item_set_delay_until (item, delay);
+			g_free (delay);
 
 		} else if (!strcmp (x_name, "X-EVOLUTION-OPTIONS-TRACKINFO")) {
 			sendoptions_set = TRUE;
@@ -458,7 +461,6 @@ set_rrule_from_comp (ECalComponent *comp, EGwItem *item, ECalBackendGroupwise *c
 		/* assumes only one rrule is present  */
 		ical_recur = (struct icalrecurrencetype *) rrule_list->data;
 
-		g_message ("DEBUG: Processing rule\n%s\n", icalrecurrencetype_as_string (ical_recur));
 		/*set the data */
 		switch (ical_recur->freq) {
 			case ICAL_DAILY_RECURRENCE :
@@ -479,7 +481,7 @@ set_rrule_from_comp (ECalComponent *comp, EGwItem *item, ECalBackendGroupwise *c
 		if (ical_recur->count != 0)
 			item_rrule->count = ical_recur->count;
 		else
-			item_rrule->until =  g_strdup (icaltime_as_ical_string (ical_recur->until));
+			item_rrule->until =  icaltime_as_ical_string (ical_recur->until);
 
 		item_rrule->interval = ical_recur->interval;
 
@@ -511,7 +513,7 @@ set_rrule_from_comp (ECalComponent *comp, EGwItem *item, ECalBackendGroupwise *c
 					if (!icaltime_get_timezone (*(dt->value)))
 						icaltime_set_timezone (dt->value, default_zone ? default_zone : utc);
 					itt_utc = icaltime_convert_to_zone (*dt->value, utc);
-					item_exdate_list = g_slist_append (item_exdate_list, g_strdup (icaltime_as_ical_string (itt_utc)));
+					item_exdate_list = g_slist_append (item_exdate_list, icaltime_as_ical_string (itt_utc));
 				}
 			}
 			e_gw_item_set_exdate_list (item, item_exdate_list);
@@ -524,6 +526,7 @@ static EGwItem *
 set_properties_from_cal_component (EGwItem *item, ECalComponent *comp, ECalBackendGroupwise *cbgw)
 {
 	const char *uid, *location;
+	char *value;
 	ECalComponentDateTime dt;
 	ECalComponentClassification classif;
 	ECalComponentTransparency transp;
@@ -567,6 +570,7 @@ set_properties_from_cal_component (EGwItem *item, ECalComponent *comp, ECalBacke
 
 			alarm = e_cal_component_get_alarm (comp, l->data);
 			e_cal_component_alarm_get_trigger (alarm, &trigger);
+			e_cal_component_alarm_free (alarm);
 			duration = abs (icaldurationtype_as_int (trigger.u.rel_duration));
 			e_gw_item_set_trigger (item, duration);
 			cal_obj_uid_list_free (l);
@@ -580,7 +584,9 @@ set_properties_from_cal_component (EGwItem *item, ECalComponent *comp, ECalBacke
 			if (!icaltime_get_timezone (*dt.value))
 				icaltime_set_timezone (dt.value, default_zone ? default_zone : utc);
 			itt_utc = icaltime_convert_to_zone (*dt.value, utc);
-			e_gw_item_set_end_date (item, icaltime_as_ical_string (itt_utc));
+			value = icaltime_as_ical_string (itt_utc);
+			e_gw_item_set_end_date (item, value);
+			g_free (value);
 			e_cal_component_free_datetime (&dt);
 		}
 
@@ -595,7 +601,9 @@ set_properties_from_cal_component (EGwItem *item, ECalComponent *comp, ECalBacke
 			if (!icaltime_get_timezone (*dt.value))
 				icaltime_set_timezone (dt.value, default_zone);
 			itt_utc = icaltime_convert_to_zone (*dt.value, utc);
-			e_gw_item_set_due_date (item, icaltime_as_ical_string (itt_utc));
+			value = icaltime_as_ical_string (itt_utc);
+			e_gw_item_set_due_date (item,  value);
+			g_free (value);
 			e_cal_component_free_datetime (&dt);
 		}
 
@@ -671,7 +679,9 @@ set_properties_from_cal_component (EGwItem *item, ECalComponent *comp, ECalBacke
 		if (!icaltime_get_timezone (*dt.value))
 			icaltime_set_timezone (dt.value, default_zone);
 		itt_utc = icaltime_convert_to_zone (*dt.value, utc);
-		e_gw_item_set_start_date (item, icaltime_as_ical_string (itt_utc));
+		value = icaltime_as_ical_string (itt_utc);
+		e_gw_item_set_start_date (item, value);
+		g_free (value);
 	} else if (e_gw_item_get_item_type (item) == E_GW_ITEM_TYPE_APPOINTMENT) {
 		e_cal_component_free_datetime (&dt);
 		/* appointments need the start date property */
@@ -692,12 +702,16 @@ set_properties_from_cal_component (EGwItem *item, ECalComponent *comp, ECalBacke
 		if (!icaltime_get_timezone (*dt.value))
 			icaltime_set_timezone (dt.value, default_zone);
 		itt_utc = icaltime_convert_to_zone (*dt.value, utc);
-		e_gw_item_set_creation_date (item, icaltime_as_ical_string (itt_utc));
+		value = icaltime_as_ical_string (itt_utc);
+		e_gw_item_set_creation_date (item, value);
+		g_free (value);
 	} else {
 		struct icaltimetype itt;
 
 		e_cal_component_get_dtstamp (comp, &itt);
-		e_gw_item_set_creation_date (item, icaltime_as_ical_string (itt));
+		value = icaltime_as_ical_string (itt);
+		e_gw_item_set_creation_date (item, value);
+		g_free (value);
 	}
 
 	e_cal_component_free_icaltimetype (dt.value);
@@ -856,6 +870,9 @@ set_attachments_to_cal_component (EGwItem *item, ECalComponent *comp, ECalBacken
 
 	e_cal_component_set_attachment_list (comp, comp_attachment_list);
 
+	for (l = comp_attachment_list; l != NULL; l = l->next) 
+		g_free (l->data);
+	g_slist_free (comp_attachment_list);
 }
 
 static void
@@ -924,6 +941,23 @@ set_default_alarms (ECalComponent *comp)
 }
 
 
+static char *
+get_cn_from_display_name (char *display_name)
+{	
+	char *dn;
+	
+	/* Strip the name part alone as the display name might contain email also*/
+	dn = g_strstr_len (display_name, strlen (display_name), " <");
+
+	if (!dn)
+		return g_strdup (display_name);
+	else { 
+		dn = g_strndup (display_name, (dn - display_name));
+		dn = g_strdelimit (dn, "\"", ' ');
+		return dn;
+	}	
+}
+
 ECalComponent *
 e_gw_item_to_cal_component (EGwItem *item, ECalBackendGroupwise *cbgw)
 {
@@ -1134,7 +1168,7 @@ e_gw_item_to_cal_component (EGwItem *item, ECalBackendGroupwise *cbgw)
 				EGwItemRecipient *recipient = (EGwItemRecipient *) rl->data;
 				ECalComponentAttendee *attendee = g_new0 (ECalComponentAttendee, 1);
 
-				attendee->cn = g_strdup (recipient->display_name);
+				attendee->cn = get_cn_from_display_name (recipient->display_name);
 				attendee->value = g_strconcat("MAILTO:", recipient->email, NULL);
 				if (recipient->type == E_GW_ITEM_RECIPIENT_TO)
 					attendee->role = ICAL_ROLE_REQPARTICIPANT;
@@ -1164,6 +1198,14 @@ e_gw_item_to_cal_component (EGwItem *item, ECalBackendGroupwise *cbgw)
 			}
 
 			e_cal_component_set_attendee_list (comp, attendee_list);
+
+			for (rl = attendee_list; rl != NULL; rl = rl->next) {
+				ECalComponentAttendee *att = rl->data;
+				g_free ((char *) att->cn);
+				g_free ((char *) att->value);
+				g_free (att);
+			}
+			g_slist_free (attendee_list);
 		}
 	}
 
@@ -1173,9 +1215,13 @@ e_gw_item_to_cal_component (EGwItem *item, ECalBackendGroupwise *cbgw)
 		ECalComponentOrganizer *cal_organizer;
 
 		cal_organizer = g_new0 (ECalComponentOrganizer, 1);
-		cal_organizer->cn = g_strdup (organizer->display_name);
+		cal_organizer->cn = get_cn_from_display_name (organizer->display_name);
 		cal_organizer->value = g_strconcat("MAILTO:", organizer->email, NULL);
 		e_cal_component_set_organizer (comp, cal_organizer);
+
+		g_free ((char *) cal_organizer->cn);
+		g_free ((char*) cal_organizer->value);
+		g_free (cal_organizer);
 	}
 
 	/* set attachments, if any */
@@ -1530,7 +1576,7 @@ start_freebusy_session (EGwConnection *cnc, GList *users,
         GList *l;
         icaltimetype icaltime;
 	icaltimezone *utc;
-        const char *start_date, *end_date;
+        char *start_date, *end_date;
 
 	if (users == NULL)
                 return E_GW_CONNECTION_STATUS_INVALID_OBJECT;
@@ -1561,6 +1607,8 @@ start_freebusy_session (EGwConnection *cnc, GList *users,
 
         e_gw_message_write_string_parameter (msg, "startDate", NULL, start_date);
         e_gw_message_write_string_parameter (msg, "endDate", NULL, end_date);
+	g_free (start_date);
+	g_free (end_date);
 
 	e_gw_message_write_footer (msg);
 
@@ -1630,7 +1678,8 @@ e_gw_connection_get_freebusy_info (EGwConnection *cnc, GList *users, time_t star
         SoupSoapResponse *response;
         EGwConnectionStatus status;
         SoupSoapParameter *param, *subparam, *param_outstanding;
-        const char *session, *outstanding = NULL;
+        const char *session;
+	char *outstanding = NULL;
 	gboolean resend_request = TRUE;
 	int request_iteration = 0;
 
@@ -1684,8 +1733,10 @@ e_gw_connection_get_freebusy_info (EGwConnection *cnc, GList *users, time_t star
 		g_object_unref (msg);
 		g_object_unref (response);
 		g_usleep (10000000);
+		g_free (outstanding); outstanding = NULL;
 		goto resend;
 	}
+	g_free (outstanding); outstanding = NULL;
 
         /* FIXME  the FreeBusyStats are not used currently.  */
         param = soup_soap_response_get_first_parameter_by_name (response, "freeBusyInfo");
@@ -1701,7 +1752,7 @@ e_gw_connection_get_freebusy_info (EGwConnection *cnc, GList *users, time_t star
 	     subparam != NULL;
 	     subparam = soup_soap_parameter_get_next_child_by_name (subparam, "user")) {
 		SoupSoapParameter *param_blocks, *subparam_block, *tmp;
-		const char *uuid = NULL, *email = NULL, *name = NULL;
+		char *uuid = NULL, *email = NULL, *name = NULL;
 		ECalComponent *comp;
 		ECalComponentAttendee attendee;
 		GSList *attendee_list = NULL;
@@ -1734,11 +1785,14 @@ e_gw_connection_get_freebusy_info (EGwConnection *cnc, GList *users, time_t star
 
 		/* XXX the uuid is not currently used. hence it is
 		 * discarded */
+		g_free (uuid); uuid = NULL;
 
 		attendee_list = g_slist_append (attendee_list, &attendee);
 
 		e_cal_component_set_attendee_list (comp, attendee_list);
-
+		g_slist_free (attendee_list);
+		g_free ((char *) name);
+		g_free ((char *) email);
 
 		param_blocks = soup_soap_parameter_get_first_child_by_name (subparam, "blocks");
 		if (!param_blocks) {
@@ -1757,7 +1811,7 @@ e_gw_connection_get_freebusy_info (EGwConnection *cnc, GList *users, time_t star
 			icalproperty *icalprop;
 			icaltimetype itt;
 			time_t t;
-			const char *start, *end, *accept_level;
+			char *start, *end, *accept_level;
 
 			memset (&ipt, 0, sizeof (struct icalperiodtype));
 			tmp = soup_soap_parameter_get_first_child_by_name (subparam_block, "startDate");
@@ -1766,6 +1820,7 @@ e_gw_connection_get_freebusy_info (EGwConnection *cnc, GList *users, time_t star
 				t = e_gw_connection_get_date_from_string (start);
 				itt = icaltime_from_timet_with_zone (t, 0, default_zone ? default_zone : NULL);
 				ipt.start = itt;
+				g_free (start);
 			}
 
 			tmp = soup_soap_parameter_get_first_child_by_name (subparam_block, "endDate");
@@ -1774,6 +1829,7 @@ e_gw_connection_get_freebusy_info (EGwConnection *cnc, GList *users, time_t star
 				t = e_gw_connection_get_date_from_string (end);
 				itt = icaltime_from_timet_with_zone (t, 0, default_zone ? default_zone : NULL);
 				ipt.end = itt;
+				g_free (end);
 			}
 			icalprop = icalproperty_new_freebusy (ipt);
 
@@ -1788,9 +1844,9 @@ e_gw_connection_get_freebusy_info (EGwConnection *cnc, GList *users, time_t star
 					icalproperty_set_parameter_from_string (icalprop, "FBTYPE", "BUSYUNAVAILABLE");
 				else if (!strcmp (accept_level, "Free"))
 					icalproperty_set_parameter_from_string (icalprop, "FBTYPE", "FREE");
-							}
+				g_free (accept_level);
+			}
 			icalcomponent_add_property(icalcomp, icalprop);
-
 		}
 
 		e_cal_component_commit_sequence (comp);
@@ -1998,7 +2054,7 @@ e_cal_backend_groupwise_store_settings (GwSettings *hold)
 
 		/* Delay delivery */
 		if (gopts->delay_enabled) {
-			const char *value;
+			char *value;
 			tt = icaltime_today ();
 			icaltime_adjust (&tt, gopts->delay_until, 0, 0, 0);
 			value = icaltime_as_ical_string (tt);
