@@ -652,6 +652,7 @@ imap_rescan (CamelFolder *folder, int exists, CamelException *ex)
 {
 	CamelImapFolder *imap_folder = CAMEL_IMAP_FOLDER (folder);
 	CamelImapStore *store = CAMEL_IMAP_STORE (folder->parent_store);
+	extern int camel_application_is_exiting;
 	struct {
 		char *uid;
 		guint32 flags;
@@ -665,6 +666,9 @@ imap_rescan (CamelFolder *folder, int exists, CamelException *ex)
 	gboolean ok;
 	CamelFolderChangeInfo *changes = NULL;
 
+ 	if (camel_application_is_exiting)
+ 		return;
+ 	
 	imap_folder->need_rescan = FALSE;
 
 	summary_len = camel_folder_summary_count (folder->summary);
@@ -970,7 +974,7 @@ imap_sync_online (CamelFolder *folder, CamelException *ex)
 		/* FIXME: since we don't know the previously set flags,
 		   if unset is TRUE then just unset all the flags? */
 		/* FIXME: Sankar: What about custom flags ? */
-		flaglist = imap_create_flag_list (unset ? folder->permanent_flags : info->info.flags & folder->permanent_flags, (CamelMessageInfo *)info);
+		flaglist = imap_create_flag_list (unset ? folder->permanent_flags : info->info.flags & folder->permanent_flags, (CamelMessageInfo *)info, folder->permanent_flags);
 
 		/* Note: to `unset' flags, use -FLAGS.SILENT (<flag list>) */
 		response = camel_imap_command (store, folder, &local_ex,
@@ -1362,7 +1366,7 @@ retry:
 
 	flags &= folder->permanent_flags;
 	if (flags)
-		flagstr = imap_create_flag_list (flags, (CamelMessageInfo *)info);
+		flagstr = imap_create_flag_list (flags, (CamelMessageInfo *)info, folder->permanent_flags);
 	else
 		flagstr = NULL;
 
@@ -2751,8 +2755,10 @@ imap_update_summary (CamelFolder *folder, int exists,
 		camel_folder_summary_add (folder->summary, (CamelMessageInfo *)mi);
 		camel_folder_change_info_add_uid (changes, camel_message_info_uid (mi));
 
-		if ((mi->info.flags & CAMEL_IMAP_MESSAGE_RECENT)) 
-			camel_folder_change_info_recent_uid(changes, camel_message_info_uid (mi));
+		/* report all new messages as recent, even without that flag, thus new
+		   messages will be filtered even after saw by other software earlier */
+		if ((mi->info.flags & CAMEL_IMAP_MESSAGE_RECENT) != 0 || getenv ("FILTER_RECENT") == NULL)
+			camel_folder_change_info_recent_uid (changes, camel_message_info_uid (mi));
 	}
 
 	for ( ; i < messages->len; i++) {
@@ -2787,6 +2793,7 @@ camel_imap_folder_changed (CamelFolder *folder, int exists,
 			   GArray *expunged, CamelException *ex)
 {
 	CamelImapFolder *imap_folder = CAMEL_IMAP_FOLDER (folder);
+	extern int camel_application_is_exiting;
 	CamelFolderChangeInfo *changes;
 	CamelMessageInfo *info;
 	int len;
@@ -2814,7 +2821,7 @@ camel_imap_folder_changed (CamelFolder *folder, int exists,
 	}
 
 	len = camel_folder_summary_count (folder->summary);
-	if (exists > len)
+	if (exists > len && !camel_application_is_exiting)
 		imap_update_summary (folder, exists, changes, ex);
 
 	if (camel_folder_change_info_changed (changes))
