@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef _CAMEL_MAILDIR_SUMMARY_H
@@ -41,7 +41,7 @@ typedef struct _CamelMaildirMessageContentInfo {
 
 enum {
 	CAMEL_MAILDIR_INFO_FILENAME = CAMEL_MESSAGE_INFO_LAST,
-	CAMEL_MAILDIR_INFO_LAST,
+	CAMEL_MAILDIR_INFO_LAST
 };
 
 typedef struct _CamelMaildirMessageInfo {
